@@ -24,14 +24,15 @@ CONFIGURATION_HOLIDAYS = '1.0/Configuration/Holidays'
 CONFIGURATION_IS_LOCAL_HOLIDAY = '1.0/Configuration/IsLocalHoliday'
 CONFIGURATION_IS_USA_HOLIDAY = '1.0/Configuration/IsUSAHoliday'
 
-MARKETDATA_SEARCH_INSTRUMENT = '1.0/MarketData/SearchInstrument'
-MARKETDATA_SEARCH = '1.0/MarketData/Search'
-MARKETDATA_CURRENT = '1.0/MarketData/Current'
-MARKETDATA_BOOK = '1.0/MarketData/Book'
-MARKETDATA_INTRADAY = '1.0/MarketData/Intraday'
+MARKETDATA_SEARCH_INSTRUMENT = '1.0/MarketData/SearchInstrument?ticker={0}&name={1}&market={2}&type={3}'
+MARKETDATA_SEARCH = '1.0/MarketData/Search?ticker={0}&type={1}&dateFrom={2}&dateTo={3}&settlement={4}'
+MARKETDATA_CURRENT = '1.0/MarketData/Current?ticker={0}&type={1}&settlement={2}'
+MARKETDATA_BOOK = '1.0/MarketData/Book?ticker={0}&type={1}&settlement={2}'
+MARKETDATA_INTRADAY = '1.0/MarketData/Intraday?ticker={0}&type={1}&settlement={2}'
 
-ORDER_ORDERS = '1.0/Order/Orders?accountNumber={0}'
-ORDER_DETAIL = '1.0/Order/Detail'
+ORDER_ORDERS = '1.0/Order/Orders?accountNumber={0}&dateFrom={1}&dateTo={2}'
+ORDER_ACTIVE_ORDERS = '1.0/Order/ActiveOrders?accountNumber={0}'
+ORDER_DETAIL = '1.0/Order/Detail?accountNumber={0}&orderID={1}&externalID={2}'
 ORDER_BUDGET = '1.0/Order/Budget'
 ORDER_CONFIRM = '1.0/Order/Confirm'
 ORDER_CANCEL = '1.0/Order/Cancel'
