@@ -1,11 +1,10 @@
 from ppi_client.api.constants import ORDER_ORDERS, ORDER_DETAIL, \
-    ORDER_BUDGET, ORDER_CONFIRM, ORDER_CANCEL, ORDER_MASS_CANCEL
+    ORDER_BUDGET, ORDER_CONFIRM, ORDER_CANCEL, ORDER_MASS_CANCEL, ORDER_ACTIVE_ORDERS
 from ppi_client.ppi_api_client import PPIClient
 from ppi_client.models.order import Order
 from ppi_client.models.order_budget import OrderBudget
 from ppi_client.models.order_confirm import OrderConfirm
-from ppi_client.models.orders_filter import OrdersFilter
-
+from datetime import datetime
 
 class OrdersApi(object):
     __api_client: PPIClient
@@ -13,33 +12,33 @@ class OrdersApi(object):
     def __init__(self, api_client):
         self.__api_client = api_client
 
-    def get_orders(self, parameters: OrdersFilter):
+    def get_orders(self, account_number: str, date_from: datetime, date_to: datetime):
         """Retrieves all the filter and active orders for the given account.
-        :param parameters: Parameters for the search: account_number: str, from_date: datetime, to_date: datetime
-        :type parameters: OrdersFilter
-        :rtype: List of orders
+        :param account_number: account number
+        :param date_from: date from
+        :param date_to: date to
+        :rtype: List of orders between two dates
         """
-        params = {
-            'dateFrom': parameters.from_date,
-            'dateTo': parameters.to_date
-        }
 
-        uri = ORDER_ORDERS.format(parameters.account_number)
-        return self.__api_client.get(uri, params)
+        return self.__api_client.get(ORDER_ORDERS.format(account_number, date_from, date_to))
 
-    def get_order_detail(self, parameters: Order):
+    def get_active_orders(self, account_number: str):
+        """Retrieves all the active orders for the given account.
+        :param account_number: account number
+        :rtype: List of active orders
+        """
+
+        return self.__api_client.get(ORDER_ACTIVE_ORDERS.format(account_number))
+
+    def get_order_detail(self, account_number: str, order_id: str, external_id: str):
         """Retrieves the information for the order.
-        :param parameters: Parameters for the search: account_number: str, orderId: int, externalID: string
-        :type parameters: Order
+        :param account_number: account number
+        :param order_id: order id
+        :param external_id: external id
         :rtype: Order information
         """
-        body = {
-            "accountNumber": parameters.account_number,
-            "orderID": parameters.id,
-            "externalID": parameters.externalId
-        }
 
-        return self.__api_client.get(ORDER_DETAIL, data=body)
+        return self.__api_client.get(ORDER_DETAIL.format(account_number, order_id, external_id))
 
     def budget(self, parameters: OrderBudget):
         """Retrieves a budget for a new order.
