@@ -1,3 +1,4 @@
+import decimal
 from dataclasses import dataclass
 from datetime import datetime
 
@@ -6,7 +7,7 @@ from datetime import datetime
 class OrderConfirm:
     accountNumber: str
     quantity: int
-    price: int
+    price: decimal
     ticker: str
     instrumentType: str
     quantityType: str
@@ -17,4 +18,4 @@ class OrderConfirm:
     settlement: str
     disclaimers: str
     externalId: str
-
+    activationPrice: decimal = None
