@@ -26,13 +26,13 @@ class RestClient(object):
 
         self.__API_BASE_URL = "https://clientapi.portfoliopersonal.com/api/"
         self.__WS_BASE_URL = f"https://realtimeclientapi.portfoliopersonal.com/"
-        self.__WS_BASE_URL_MARKETDATA = f"wss://realtimeclientapi.portfoliopersonal.com/marketData"
+        self.__WS_BASE_URL_WS = f"wss://realtimeclientapi.portfoliopersonal.com/"
         self.__WS_TRACE = False
         self.__SSL_VERIFY = True
         if sandbox is True:
             self.__API_BASE_URL = "https://clientapi_sandbox.portfoliopersonal.com/api/"
             self.__WS_BASE_URL = f"https://realtimeclientapi-sandbox.portfoliopersonal.com/"
-            self.__WS_BASE_URL_MARKETDATA = f"wss://realtimeclientapi-sandbox.portfoliopersonal.com/marketData"
+            self.__WS_BASE_URL_WS = f"wss://realtimeclientapi-sandbox.portfoliopersonal.com/"
             self.__WS_TRACE = False
             self.__SSL_VERIFY = True
 
@@ -142,8 +142,8 @@ class RestClient(object):
             self.refresh_token_ws = res.response['refreshToken']
             return res.response['accessToken']
 
-    async def connect_to_websocket(self):
-        server_url = self.__WS_BASE_URL_MARKETDATA
+    async def connect_to_websocket(self, hub_name):
+        server_url = self.__WS_BASE_URL_WS + hub_name
         hub_connection = HubConnectionBuilder() \
             .with_url(server_url,
                       options={"verify_ssl": self.__SSL_VERIFY,
